Timelines - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Timelines

A timeline is a perfect way to visualize processes and projects, as it's easy to read and attractive for users. You can use it to give an overview of events, present an agenda or point out important points in time.

## Timeline

The available timeline design is comprised of many components that will help you visualize a process or show an outline of events. Thanks to the possibility of adding icons, avatars and links and the way of presenting the elements of content, your timeline will be clear for users and will make yor website or app more attractive.

    <div class="card">
      <div class="card-header">
        <h3 class="card-title">Timeline</h3>
      </div>
      <div class="card-body">
        <ul class="list list-timeline">
          <li>
            <div class="list-timeline-icon bg-twitter"><!-- Download SVG icon from http://tabler-icons.io/i/brand-twitter -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">10 hrs ago</div>
              <p class="list-timeline-title">+1150 Followers</p>
              <p class="text-muted">You’re getting more and more followers, keep it up!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-red"><!-- Download SVG icon from http://tabler-icons.io/i/briefcase -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 hrs ago</div>
              <p class="list-timeline-title">+3 New Products were added!</p>
              <p class="text-muted">Congratulations!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-success"><!-- Download SVG icon from http://tabler-icons.io/i/check -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">1 day ago</div>
              <p class="list-timeline-title">Database backup completed!</p>
              <p class="text-muted">Download the <a href="#">latest backup</a>.</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-facebook"><!-- Download SVG icon from http://tabler-icons.io/i/brand-facebook -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">1 day ago</div>
              <p class="list-timeline-title">+290 Page Likes</p>
              <p class="text-muted">This is great, keep it up!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-teal"><!-- Download SVG icon from http://tabler-icons.io/i/user-plus -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 days ago</div>
              <p class="list-timeline-title">+3 Friend Requests</p>
              <div class="avatar-list mt-3">
                <span class="avatar" style="background-image: url(...)">
                  <span class="badge bg-success"></span></span>
                <span class="avatar">
                  <span class="badge bg-success"></span>JL</span>
                <span class="avatar" style="background-image: url(...)">
                  <span class="badge bg-success"></span></span>
              </div>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-yellow"><!-- Download SVG icon from http://tabler-icons.io/i/photo -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">3 days ago</div>
              <p class="list-timeline-title">+2 New photos</p>
              <div class="mt-3">
                <div class="row g-2">
                  <div class="col-6">
                    <div class="media media-2x1 rounded">
                      <a class="media-content" style="background-image: url(...)"></a>
                    </div>
                  </div>
                  <div class="col-6">
                    <div class="media media-2x1 rounded">
                      <a class="media-content" style="background-image: url(...)"></a>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon"><!-- Download SVG icon from http://tabler-icons.io/i/settings -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 weeks ago</div>
              <p class="list-timeline-title">System updated to v2.02</p>
              <p class="text-muted">Check the complete changelog at the <a href="#">activity
                  page</a>.</p>
            </div>
          </li>
        </ul>
      </div>
    </div>

## Simple timeline

Use a simplified version of the timeline, if it suits your design better. You can still make use of all the available timeline components.

    <div class="card">
      <div class="card-header">
        <h3 class="card-title">Timeline</h3>
      </div>
      <div class="card-body">
        <ul class="list list-timeline list-timeline-simple">
          <li>
            <div class="list-timeline-icon bg-twitter"><!-- Download SVG icon from http://tabler-icons.io/i/brand-twitter -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">10 hrs ago</div>
              <p class="list-timeline-title">+1150 Followers</p>
              <p class="text-muted">You’re getting more and more followers, keep it up!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-red"><!-- Download SVG icon from http://tabler-icons.io/i/briefcase -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 hrs ago</div>
              <p class="list-timeline-title">+3 New Products were added!</p>
              <p class="text-muted">Congratulations!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-success"><!-- Download SVG icon from http://tabler-icons.io/i/check -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">1 day ago</div>
              <p class="list-timeline-title">Database backup completed!</p>
              <p class="text-muted">Download the <a href="#">latest backup</a>.</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-facebook"><!-- Download SVG icon from http://tabler-icons.io/i/brand-facebook -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">1 day ago</div>
              <p class="list-timeline-title">+290 Page Likes</p>
              <p class="text-muted">This is great, keep it up!</p>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-teal"><!-- Download SVG icon from http://tabler-icons.io/i/user-plus -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 days ago</div>
              <p class="list-timeline-title">+3 Friend Requests</p>
              <div class="avatar-list mt-3">
                <span class="avatar" style="background-image: url(...)">
                  <span class="badge bg-success"></span></span>
                <span class="avatar">
                  <span class="badge bg-success"></span>JL</span>
                <span class="avatar" style="background-image: url(...)">
                  <span class="badge bg-success"></span></span>
              </div>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon bg-yellow"><!-- Download SVG icon from http://tabler-icons.io/i/photo -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">3 days ago</div>
              <p class="list-timeline-title">+2 New photos</p>
              <div class="mt-3">
                <div class="row g-2">
                  <div class="col-6">
                    <div class="media media-2x1 rounded">
                      <a class="media-content" style="background-image: url(...)"></a>
                    </div>
                  </div>
                  <div class="col-6">
                    <div class="media media-2x1 rounded">
                      <a class="media-content" style="background-image: url(...)"></a>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </li>
          <li>
            <div class="list-timeline-icon"><!-- Download SVG icon from http://tabler-icons.io/i/settings -->
              <!-- SVG icon code -->
            </div>
            <div class="list-timeline-content">
              <div class="list-timeline-time">2 weeks ago</div>
              <p class="list-timeline-title">System updated to v2.02</p>
              <p class="text-muted">Check the complete changelog at the <a href="#">activity
                  page</a>.</p>
            </div>
          </li>
        </ul>
      </div>
    </div>